@@ -29,34 +29,20 @@ extern "C" {
 #include <stdarg.h>
 #include <pthread.h>
 
-#ifdef XINE_COMPILE
-#  include <inttypes.h>
-#  include "attributes.h"
-#  include "compat.h"
-#  include "xmlparser.h"
-#  include "xine_buffer.h"
-#  include "configfile.h"
-#  include "list.h"
-#  include "array.h"
-#  include "sorted_array.h"
-#  include "xine_mmx.h"
+#ifdef WIN32
+#  include <winsock.h>
 #else
-#  ifdef WIN32
-#    include <winsock.h>
-#  else
-#    include <sys/time.h>
-#  endif
-#  include <xine/os_types.h>
-#  include <xine/attributes.h>
-#  include <xine/compat.h>
-#  include <xine/xmlparser.h>
-#  include <xine/xine_buffer.h>
-#  include <xine/configfile.h>
-#  include <xine/list.h>
-#  include <xine/array.h>
-#  include <xine/sorted_array.h>
-#  include <xine/xine_mmx.h>
+#  include <sys/time.h>
 #endif
+#include <xine/os_types.h>
+#include <xine/attributes.h>
+#include <xine/compat.h>
+#include <xine/xmlparser.h>
+#include <xine/xine_buffer.h>
+#include <xine/configfile.h>
+#include <xine/list.h>
+#include <xine/array.h>
+#include <xine/sorted_array.h>
 
 #include <stdio.h>
 #include <string.h>
@@ -106,6 +92,11 @@ extern "C" {
 #define MM_ACCEL_X86_MMXEXT     0x20000000
 #define MM_ACCEL_X86_SSE        0x10000000
 #define MM_ACCEL_X86_SSE2       0x08000000
+#define MM_ACCEL_X86_SSE3       0x04000000
+#define MM_ACCEL_X86_SSSE3      0x02000000
+#define MM_ACCEL_X86_SSE4       0x01000000
+#define MM_ACCEL_X86_SSE42      0x00800000
+#define MM_ACCEL_X86_AVX        0x00400000
 
 /* powerpc accelerations and features */
 #define MM_ACCEL_PPC_ALTIVEC    0x04000000
@@ -131,12 +122,6 @@ uint32_t xine_mm_accel (void) XINE_CONST XINE_PROTECTED;
 
 extern void *(* xine_fast_memcpy)(void *to, const void *from, size_t len) XINE_PROTECTED;
 
-#ifdef HAVE_XINE_INTERNAL_H
-/* Benchmark available memcpy methods */
-void xine_probe_fast_memcpy(xine_t *xine) XINE_PROTECTED;
-#endif
-
-
 /*
  * Debug stuff
  */
@@ -155,12 +140,13 @@ void xine_profiler_print_results (void) XINE_PROTECTED;
  */
 void *xine_xmalloc(size_t size) XINE_MALLOC XINE_DEPRECATED XINE_PROTECTED;
 
+void *xine_xcalloc(size_t nmemb, size_t size) XINE_MALLOC XINE_PROTECTED;
+
 /*
- * Same as above, but memory is aligned to 'alignement'.
- * **base is used to return pointer to un-aligned memory, use
- * this to free the mem chunk
+ * Copy blocks of memory.
  */
-void *xine_xmalloc_aligned(size_t alignment, size_t size, void **base) XINE_PROTECTED;
+void *xine_memdup (const void *src, size_t length) XINE_MALLOC XINE_PROTECTED;
+void *xine_memdup0 (const void *src, size_t length) XINE_MALLOC XINE_PROTECTED;
 
 /*
  * Get user home directory.
@@ -188,21 +174,6 @@ char *xine_chomp (char *str) XINE_PROTECTED;
  */
 void xine_usec_sleep(unsigned usec) XINE_PROTECTED;
 
-
-  /*
-   * Some string functions
-   */
-
-
-void xine_strdupa(char *dest, char *src) XINE_PROTECTED XINE_DEPRECATED;
-#define xine_strdupa(d, s) do {                                             \
-                                (d) = NULL;                                 \
-                                if((s) != NULL) {                           \
-                                  (d) = (char *) alloca(strlen((s)) + 1);   \
-                                  strcpy((d), (s));                         \
-                                }                                           \
-                              } while(0)
-
 /* compatibility macros */
 #define xine_strpbrk(S, ACCEPT) strpbrk((S), (ACCEPT))
 #define xine_strsep(STRINGP, DELIM) strsep((STRINGP), (DELIM))
@@ -215,6 +186,32 @@ void xine_strdupa(char *dest, char *src) XINE_PROTECTED XINE_DEPRECATED;
  */
 char *xine_strcat_realloc (char **dest, char *append) XINE_PROTECTED;
 
+/**
+ * asprintf wrapper
+ * allocate a string large enough to hold the output, and return a pointer to
+ * it. This pointer should be passed to free when it is no longer needed.
+ * return NULL on error.
+ */
+char *_x_asprintf(const char *format, ...) XINE_PROTECTED XINE_MALLOC XINE_FORMAT_PRINTF(1, 2);
+
+/**
+ * opens a file, ensuring that the descriptor will be closed
+ * automatically after a fork/execute.
+ */
+int xine_open_cloexec(const char *name, int flags) XINE_PROTECTED;
+
+/**
+ * creates a file, ensuring that the descriptor will be closed
+ * automatically after a fork/execute.
+ */
+int xine_create_cloexec(const char *name, int flags, mode_t mode) XINE_PROTECTED;
+
+/**
+ * creates a socket, ensuring that the descriptor will be closed
+ * automatically after a fork/execute.
+ */
+int xine_socket_cloexec(int domain, int type, int protocol) XINE_PROTECTED;
+
 /*
  * Color Conversion Utility Functions
  * The following data structures and functions facilitate the conversion
@@ -265,6 +262,9 @@ extern void (*yuy2_to_yv12)
 #define SCALEFACTOR 65536
 #define CENTERSAMPLE 128
 
+/* These conversions are normalised for the MPEG Y'CbCr colourspace.
+ * (Yes, we know that we call it YUV elsewhere.)
+ */
 #define COMPUTE_Y(r, g, b) \
   (unsigned char) \
   ((y_r_table[r] + y_g_table[g] + y_b_table[b]) / SCALEFACTOR)
@@ -319,7 +319,7 @@ extern void yuy2_to_yuy2
    int width, int height) XINE_PROTECTED;
 
 /* print a hexdump of the given data */
-void xine_hexdump (const char *buf, int length) XINE_PROTECTED;
+void xine_hexdump (const void *buf, int length) XINE_PROTECTED;
 
 /*
  * Optimization macros for conditions
@@ -508,6 +508,12 @@ const char *xine_guess_spu_encoding(void) XINE_PROTECTED;
  */
 int xine_monotonic_clock(struct timeval *tv, struct timezone *tz) XINE_PROTECTED;
 
+/**
+ * Unknown FourCC reporting functions
+ */
+void _x_report_video_fourcc (xine_t *, const char *module, uint32_t) XINE_PROTECTED;
+void _x_report_audio_format_tag (xine_t *, const char *module, uint32_t) XINE_PROTECTED;
+
 /* don't harm following code */
 #ifdef extern
 #  undef extern
